# encoding: utf-8

# File:	clients/iprint_auto.ycp
# Package:	Configuration of iprint
# Summary:	Client for autoinstallation
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: iprint_auto.ycp,v 1.1.2.3 2005/04/21 17:15:47 rhaslam Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of iprint settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("iprint_auto", [ "Summary", mm ]);
module Yast
  class IprintAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-iprint"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Iprint auto started")

      Yast.import "Iprint"
      Yast.include self, "novell-iprint/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(Iprint.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        Iprint.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        #    import "OesLdap";
        #    OesLdap::autoyast_tool = true;
        @ret = IprintAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = Iprint.Import(@param)
      # Return actual state
      elsif @func == "Export"
        Iprint.Read if Iprint.Settings == nil || Iprint.Settings == {}
        Iprint.auto_clone = true
        @ret = Iprint.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = Iprint.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Iprint.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        Iprint.write_only = true
        @ret = Iprint.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        Iprint.globals_configured = true
        @ret = Iprint.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        Iprint.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Iprint auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::IprintAutoClient.new.main
