# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/iprint_proposal.ycp
# Package:	Configuration of iprint
# Summary:	Proposal function dispatcher.
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: iprint_proposal.ycp,v 1.1.2.7 2005/02/10 21:20:32 sbunch Exp $
#
# Proposal function dispatcher for iprint configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class IprintProposalClient < Client
    def main

      textdomain "novell-iprint"

      Yast.import "Iprint"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellUtils"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Iprint proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if NovellUtils.EdirAskUserFlag("iprint") # If edir changed, then we need to recompute the defaults.
          @force_reset = true
          Builtins.y2milestone(
            "iprint.MakeProposal:force_reset set to true due to ask user flag."
          )
        end

        if @force_reset || !Iprint.proposal_valid
          Iprint.proposal_valid = true
          @progress_orig = Progress.set(false)
          Iprint.Read
          Progress.set(@progress_orig)
        end
        @sum = Iprint.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("iprint", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }
          if Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ) == "" &&
              Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
              Ops.get_string(Iprint.Settings, "CONFIG_IPRINT_LDAP_SERVER", "") == ""
            Ops.set(@ret, "errors", true)
          end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("iPrint proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "iprint--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "iprint", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "iprint--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "iprint", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = Iprint.Export
          @seq = Convert.to_symbol(
            WFM.CallFunction("iprint", [path(".propose")])
          )
          Iprint.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-iprint") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("iprint")
        Builtins.y2milestone(
          "Proposal:IsSelected:novell-iprint: %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Iprint in proposals
            "rich_text_title" => _(
              "iPrint"
            ),
            # Menu title for Iprint in proposals
            "menu_title"      => _(
              "i&Print"
            ),
            "id"              => "iprint"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        Iprint.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Iprint proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::IprintProposalClient.new.main
