# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/novell-iprint/dialogs.ycp
# Package:	Configuration of iprint
# Summary:	Dialogs definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: dialogs.ycp,v 1.1.2.13 2005/07/29 00:56:46 mclark Exp $
module Yast
  module NovellIprintDialogsInclude
    def initialize_novell_iprint_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-iprint"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Iprint"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "NovellLdapBrowser"
      Yast.import "Edirectory"
      Yast.include include_target, "novell-iprint/complex.rb"
      Yast.include include_target, "novell-iprint/helps.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if Iprint.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true
        end # if this value is set at all, then it is the eDir admin (in spite of xad name)
      end
      Builtins.y2milestone(
        "ipring.PromptIfNeededForEdirAdminPassword:use xad:%1",
        useXad
      )

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end
      Builtins.y2milestone(
        "iprint.PromptIfNeededForEdirAdminPassword:useXad %1",
        useXad
      )
      useXad
    end




    # Iprint2 dialog
    # @return dialog result
    def Iprint2Dialog
      if Mode.update || Mode.autoupgrade
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "Iprint.Iprint2Dialog:skipping GUI since we are in upgrade mode."
        )
        return :skip
      end

      # iPrint configure2 dialog caption
      caption = _("iPrint Configuration")

      ldap_server = Ops.get_string(
        Iprint.Settings,
        "CONFIG_IPRINT_LDAP_SERVER",
        ""
      )
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )

      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("Directory Server Address"),
        ldap_server,
        true,
        :combo
      )
      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      top_context = Ops.get_string(
        Iprint.Settings,
        "CONFIG_IPRINT_TOP_CONTEXT",
        ""
      )

      contents = HVSquash(
        VBox(
          ldap_widget,
          MinWidth(
            45,
            HBox(
              TextEntry(
                Id(:top_context),
                _("&eDirectory search context (e.g. o=microfocus)"),
                top_context
              ),
              VBox(Label(""), PushButton(Id(:browse), _("Browse")))
            )
          )
        )
      )

      helps = Ops.get_string(server_list_widget, "helps", "")
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.add(helps, Ops.get_string(@HELPS, "ldap_context", "")),
        Label.BackButton,
        Label.NextButton
      )

      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse), :Enabled, true)
      end


      PromptIfNeededForEdirAdminPassword()

      ret = nil
      while true
        ret = UI.UserInput
        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          ldap_server = Convert.to_string(
            UI.QueryWidget(Id(:server_select), :Value)
          )
          Ops.set(Iprint.Settings, "CONFIG_IPRINT_LDAP_SERVER", ldap_server)

          top_context = Convert.to_string(
            UI.QueryWidget(Id(:top_context), :Value)
          )
          top_context = NovellUtils.Strip(top_context, " \n \t")
          top_context = "" if top_context == nil || top_context == " "

          if top_context != ""
            next if !NovellValidators.ValidateContext(top_context)
            if Builtins.findfirstof(",.", top_context) != nil
              Popup.Error(
                _(
                  "A single container must be specified (e.g. 'o=microfocus', not 'ou=provo.o=microfocus')."
                )
              )
              next
            end
          end
          Ops.set(Iprint.Settings, "CONFIG_IPRINT_TOP_CONTEXT", top_context)
          break
        elsif ret == :browse
          primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
          ldap_servers = Ops.get_string(
            primary_server,
            "CONFIG_LDAP_SERVER_IP",
            ""
          )
          ldap_sport = Ops.get_integer(
            primary_server,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Iprint.xadMode
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "NovellLum:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("Iprint:admin:%1", adminDn)
          top_context2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              top_context2
            )
          )
          if top_context2 != nil && top_context2 != ""
            top_context2 = NovellUtils.Nds2Ldap(top_context2)
            UI.ChangeWidget(Id(:top_context), :Value, top_context2)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
