# encoding: utf-8

# File:	include/novell-iprint/wizards.ycp
# Package:	Configuration of iprint
# Summary:	Wizards definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: wizards.ycp,v 1.1.2.3 2004/12/03 00:04:42 sbunch Exp $
module Yast
  module NovellIprintWizardsInclude
    def initialize_novell_iprint_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-iprint"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-iprint/complex.rb"
      Yast.include include_target, "novell-iprint/dialogs.rb"
    end

    # Main workflow of the iprint configuration
    # @return sequence result
    def MainSequence
      aliases = { "serverinfo" => lambda { Iprint2Dialog() } }

      sequence = {
        "ws_start"   => "serverinfo",
        "serverinfo" => { :abort => :abort, :next => :next, :skip => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of iprint
    # @return sequence result
    def IprintSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("iprint")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of iprint but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def IprintAutoSequence
      # Initialization dialog caption
      caption = _("iPrint Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("iprint")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
